runoutPareaPredict.RdThresholds a prediction raster of source areas (probabilities) and computes corresponding runout process areas.
runoutPareaPredict( source_pred, dem, source_threshold, rw_slp, rw_exp, rw_per, pcm_mu, pcm_md, gpp_iter = 1000, saga_lib, file_name = NULL )
| source_pred | RasterLayer with probability of being runout source area |
|---|---|
| dem | A DEM as a RasterLayer object |
| source_threshold | A cutoff of value of source area prediction |
| rw_slp | Random walk slope threshold - below lateral spreading is modeled |
| rw_exp | Random walk exponent controlling lateral spread |
| rw_per | Random walk persistence factor to weight flow direction consistency |
| pcm_mu | PCM model sliding friction coefficient |
| pcm_md | PCM model mass-to-drag ratio (m) |
| gpp_iter | Model iterations |
| saga_lib | The initiated SAGA-GIS geoprocessor object |
| file_name | (optional) Can give a file name to save process area raster as GeoTiff |
A RasterLayer with runout process areas